@@ -196,12 +196,12 @@ class ASDFDataSet(object):
             self.__file.attrs["file_format_version"] = \
                 self._zeropad_ascii_string(FORMAT_VERSION)
 
-        # Create the waveform and provenance groups.
-        if "Waveforms" not in self.__file:
+        # Create the waveform and provenance groups if mode is not "r".
+        if "Waveforms" not in self.__file and mode != "r":
             self.__file.create_group("Waveforms")
-        if "Provenance" not in self.__file:
+        if "Provenance" not in self.__file and mode != "r":
             self.__file.create_group("Provenance")
-        if "AuxiliaryData" not in self.__file:
+        if "AuxiliaryData" not in self.__file and mode != "r":
             self.__file.create_group("AuxiliaryData")
 
         # Easy access to the waveforms.
@@ -716,7 +716,7 @@ class ASDFDataSet(object):
         # Get time of first and time of last sample.
         data_starttime = obspy.UTCDateTime(
             float(data.attrs["starttime"]) / 1.0E9)
-        data_endtime = data_starttime + (idx_end - 1) * dt
+        data_endtime = data_starttime + float((idx_end - 1) * dt)
 
         # Modify the data indices to restrict the data if necessary.
         if starttime is not None and starttime > data_starttime:
